@@ -17,12 +17,13 @@ neighbor_mesh <- function(meshcode, contains = TRUE) {
   if (size < units::as_units(0.5, "km")) {
     rlang::inform("Too small meshsize. Enable 80km to 500m size.")
   }
-  res <- if (size >= units::as_units(1, "km"))
+  res <- if (size >= units::as_units(1, "km")) {
     find_neighbor_mesh(meshcode, contains = contains) # nolint
-  else if (size == units::as_units(0.5, "km"))
+  } else if (size == units::as_units(0.5, "km")) {
     find_neighbor_finemesh(meshcode, contains = contains) # nolint
-  else
+  } else {
     NULL
+  }
   return(res)
 }
 
@@ -61,40 +62,45 @@ find_neighbor_mesh <- function(meshcode = NULL, contains = TRUE) { # nolint
   } else if (size == units::as_units(1, "km")) {
     if (is_corner(meshcode)) {
       if (grepl("(00|09|90|99|010[1-8]|[1-8]9|[1-8]0|9[1-8]|0[1-8])$", meshcode)) {
-        res <- meshcode - if (grepl("0000$", meshcode)) 
+        res <- 
+          meshcode - 
+          if (grepl("0000$", meshcode)) {
           c(9281, -10, -11, 9291, 0, -1, 1002201, 992910, 992909)
-        else if (grepl("0[1-9]00$", meshcode))
+        } else if (grepl("0[1-9]00$", meshcode)) {
           c(81, -10, -11, 91, 0, -1, 993001, 992910, 992909)
-        else if (grepl("[1-9]000$", meshcode))
+        } else if (grepl("[1-9]000$", meshcode)) {
           c(9281, -10, -11, 9291, 0, -1, 10201, 910, 909)
-        else if (grepl("[0-9][1-9]00$", meshcode))
-          c(81, -10, -11, 91, 0, -1, 1001, 910, 909)          
-        else if (grepl("[1-9][0-9]09$", meshcode))
+        } else if (grepl("[0-9][1-9]00$", meshcode)) {
+          c(81, -10, -11, 91, 0, -1, 1001, 910, 909)
+        } else if (grepl("[1-9][0-9]09$", meshcode)) {
           c(-9, -10, -101, 1, 0, -91, 911, 910, 819) # 51331109 
-        else if (grepl("0[0-9]09$", meshcode))
+        } else if (grepl("0[0-9]09$", meshcode)) {
           c(-9, -10, -101, 1, 0, -91, 992911, 992910, 992819)
-        else if (grepl("0009$", meshcode))
-          c(-9, -10, -101, 1, 0, -91, 992911, 992910, 992819)          
-        else if (grepl("[0-9][1-9]90$", meshcode))
+        } else if (grepl("0009$", meshcode)) {
+          c(-9, -10, -101, 1, 0, -91, 992911, 992910, 992819)
+        } else if (grepl("[0-9][1-9]90$", meshcode)) {
           c(-819, -910, -911, 91, 0, -1, 101, 10, 9)
-        else if (grepl("[0-9]090$", meshcode))
+        } else if (grepl("[0-9]090$", meshcode)) {
           c(8381, -910, -911, 9291, 0, -1, 9301, 10, 9)
-        else if (grepl("99$", meshcode))
+        } else if (grepl("99$", meshcode)) {
           c(-909, -910, -1001, 1, 0, -91, 11, 10, -81)
-        else if (grepl("(0[1-9]0[1-8])$", meshcode))
+        } else if (grepl("(0[1-9]0[1-8])$", meshcode)) {
           c(-9, -10, -11, 1, 0, -1, 992911, 992910, 992909)
-        else if (grepl("([1-8]9)$", meshcode))
+        } else if (grepl("([1-8]9)$", meshcode)) {
           c(-9, -10, -101, 1, 0, -91, 11, 10, -81)
-        else if (grepl("[0-9][1-9][1-8]0$", meshcode))
+        } else if (grepl("[0-9][1-9][1-8]0$", meshcode)) {
           c(81, -10, -11, 91, 0, -1, 101, 10, 9)
-        else if (grepl("[0-9]0[1-8]0$", meshcode))
+        } else if (grepl("[0-9]0[1-8]0$", meshcode)) {
           c(9281, -10, -11, 9291, 0, -1, 9301, 10, 9)
-        else if (grepl("9[1-8]$", meshcode))
+        } else if (grepl("[0-6][0-9]9[1-8]$", meshcode)) {
           c(-909, -910, -911, 1, 0, -1, 11, 10, 9) # 53394592
-        else if (grepl("[1-9][0-9]0[1-8]$", meshcode))
+        } else if (grepl("7[0-9]9[1-8]$", meshcode)) {
+          c(-992909, -992910, -992911, 1, 0, -1, 11, 10, 9) # 65417592
+        } else if (grepl("[1-9][0-9]0[1-8]$", meshcode)) {
           c(-9, -10, -11, 1, 0, -1, 911, 910, 909)
-        else if (grepl("0[0-9]0[1-8]$", meshcode))
+        } else if (grepl("0[0-9]0[1-8]$", meshcode)) {
           c(-9, -10, -11, 1, 0, -1, 992911, 992910, 992909)
+        }
       }} else {
         res <- meshcode + c(9, 10, 11, -1, 0, 1, -9, -10, -11)
       }}
@@ -109,7 +115,7 @@ find_neighbor_mesh <- function(meshcode = NULL, contains = TRUE) { # nolint
 find_neighbor_finemesh <- function(meshcode, contains = TRUE) {
   relate <- NULL
   df_poly <-
-    substr(meshcode, 1, nchar(eval(meshcode)) - 1) %>%
+    coarse_gather(meshcode) %>%
     find_neighbor_mesh() %>% # nolint
     purrr::map(bind_meshpolys) %>%
     purrr::reduce(rbind)
